@@ -54,3 +54,6 @@ class Rule:
         """Return `true` if rule is `targeted delivery` type"""
 
         return self.type == RuleType.TARGETED_DELIVERY
+
+    def __str__(self):
+        return f"Rule{{id:{self.id_}}}"
