@@ -66,3 +66,20 @@ def enum_from_literal(literal: str, enum_type: Type[E], default_value: E) -> E:
         return enum_type(literal)
     except ValueError:
         return default_value
+
+
+def enum_from_name_literal(literal: str, enum_type: Type[E], default_value: Optional[E]) -> Optional[E]:
+    """
+    Converts enum name literal to enum value.
+    Returns default enum value if literal does not correspond any enum name.
+    """
+    try:
+        return enum_type[literal]
+    except ValueError:
+        return default_value
+
+
+def compare_str_ignore_case(value_1: Optional[str], value_2: Optional[str]) -> bool:
+    """Comparing two strings ignoring case."""
+    return (value_1 == value_2 or
+            ((value_1 is not None and value_2 is not None) and value_1.lower() == value_2.lower()))
