@@ -1,38 +1,45 @@
 """Targeting Segment"""
 
 from typing import Optional
-from kameleoon.data.manager.visitor import Visitor
-from kameleoon.helpers.functions import enum_from_literal
 from kameleoon.configuration.rule import Rule
-from kameleoon.configuration.data_file import DataFile
+from kameleoon.data.manager.visitor import Visitor
 from kameleoon.data.manager.visitor_manager import VisitorManager
-from kameleoon.targeting.conditions.exclusive_feature_flag_condition import (
-    ExclusiveFeatureFlagCondition,
-)
-from kameleoon.targeting.conditions.sdk_language_condition import SdkLanguageCondition
+from kameleoon.helpers.functions import enum_from_literal
+from kameleoon.logging.kameleoon_logger import KameleoonLogger
+from kameleoon.managers.data.data_manager import DataManager
 from kameleoon.sdk_version import SdkVersion
+from kameleoon.targeting.conditions.exclusive_feature_flag_condition import ExclusiveFeatureFlagCondition
+from kameleoon.targeting.conditions.sdk_language_condition import SdkLanguageCondition
 from kameleoon.targeting.conditions.segment_condition import SegmentCondition
-from kameleoon.targeting.conditions.target_feature_flag_condition import (
-    TargetFeatureFlagCondition,
-)
+from kameleoon.targeting.conditions.target_feature_flag_condition import TargetFeatureFlagCondition
 from kameleoon.targeting.conditions.targeting_condition import TargetingConditionType
 
 
 class TargetingManager:
     """Manager for check visitor is targeted for rule"""
 
-    def __init__(self, visitor_manager: VisitorManager, data_file: DataFile) -> None:
+    def __init__(self, data_manager: DataManager, visitor_manager: VisitorManager) -> None:
+        self.__data_manager = data_manager
         self.__visitor_manager = visitor_manager
-        self.__data_file = data_file
 
     # pylint: disable=W0238
     def check_targeting(self, visitor_code: str, campaign_id: int, rule: Rule):
         """Check if visitor is targeted for rule"""
+        KameleoonLogger.debug(
+            "CALL: TargetingManager.check_targeting(visitor_code: %s, campaign_id: %s, rule: %s)",
+            visitor_code, campaign_id, rule
+        )
         segment = rule.targeting_segment
         if segment is None:
-            return True
-        visitor = self.__visitor_manager.get_visitor(visitor_code)
-        return segment.check_tree(lambda type: self.__get_condition_data(type, visitor, visitor_code, campaign_id))
+            targeting: Optional[bool] = True
+        else:
+            visitor = self.__visitor_manager.get_visitor(visitor_code)
+            targeting = segment.check_tree(lambda type: self.__get_condition_data(type, visitor, visitor_code,
+                                                                                  campaign_id))
+        KameleoonLogger.debug("RETURN: TargetingManager.check_targeting(visitor_code: %s, campaign_id: %s, "
+                              "rule: %s) -> (targeting: %s)",
+                              visitor_code, campaign_id, rule, targeting)
+        return targeting
 
     # pylint: disable=R0911
     def __get_condition_data(
@@ -43,29 +50,38 @@ class TargetingManager:
         campaign_id: int,
     ):
         # pylint: disable=E1101,W0212
+        KameleoonLogger.debug(
+            "CALL: TargetingManager.__get_condition_data(condition_type_literal: %s, visitor, visitor_code: %s, "
+            "campaign_id: %s)", condition_type_literal, visitor_code, campaign_id
+        )
         condition_type = enum_from_literal(
             condition_type_literal,
             TargetingConditionType,
             TargetingConditionType.UNKNOWN,
         )
+        condition_data = None
         if visitor:
             condition_data = self.__get_condition_data_by_type(visitor, condition_type)
-            if condition_data is not None:
-                return condition_data
-        if condition_type == TargetingConditionType.SEGMENT:
-            return SegmentCondition.SegmentInfo(
-                self.__data_file,
-                lambda type: self.__get_condition_data(type, visitor, visitor_code, campaign_id),
-            )
-        if condition_type == TargetingConditionType.EXCLUSIVE_FEATURE_FLAG:
-            return ExclusiveFeatureFlagCondition.ExclusiveFeatureFlagInfo(
-                campaign_id, {} if visitor is None else visitor.variations
-            )
-        if condition_type == TargetingConditionType.VISITOR_CODE:
-            return visitor_code
-        if condition_type == TargetingConditionType.SDK_LANGUAGE:
-            return SdkLanguageCondition.SdkInfo(SdkVersion.NAME, SdkVersion.VERSION)
-        return None
+        if condition_data is None:
+            if condition_type == TargetingConditionType.SEGMENT:
+                condition_data = SegmentCondition.SegmentInfo(
+                    self.__data_manager.data_file,
+                    lambda type: self.__get_condition_data(type, visitor, visitor_code, campaign_id),
+                )
+            elif condition_type == TargetingConditionType.EXCLUSIVE_FEATURE_FLAG:
+                condition_data = ExclusiveFeatureFlagCondition.ExclusiveFeatureFlagInfo(
+                    campaign_id, {} if visitor is None else visitor.variations
+                )
+            elif condition_type == TargetingConditionType.VISITOR_CODE:
+                condition_data = visitor_code
+            elif condition_type == TargetingConditionType.SDK_LANGUAGE:
+                condition_data = SdkLanguageCondition.SdkInfo(SdkVersion.NAME, SdkVersion.VERSION)
+        KameleoonLogger.debug(
+            "RETURN: TargetingManager.__get_condition_data(condition_type_literal: %s, visitor, visitor_code: %s,"
+            " campaign_id: %s) -> (condition_data: %s)",
+            condition_type_literal, visitor_code, campaign_id, condition_data
+        )
+        return condition_data
 
     def __get_condition_data_by_type(self, visitor: Visitor, condition_type: TargetingConditionType):
         if condition_type == TargetingConditionType.BROWSER:
@@ -90,7 +106,7 @@ class TargetingManager:
         ):
             return visitor.page_view_visits
         if condition_type == TargetingConditionType.TARGET_FEATURE_FLAG:
-            return TargetFeatureFlagCondition.TargetFeatureFlagInfo(self.__data_file, visitor.variations)
+            return TargetFeatureFlagCondition.TargetFeatureFlagInfo(self.__data_manager.data_file, visitor.variations)
         if condition_type in (
             TargetingConditionType.FIRST_VISIT,
             TargetingConditionType.LAST_VISIT,
